<?php

namespace Drupal\facets_date_range_picker\Plugin\facets\processor;

use Drupal\facets\FacetInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\facets\Processor\BuildProcessorInterface;
use Drupal\facets\Processor\ProcessorPluginBase;

/**
 * Processes the date range picker input.
 *
 * @FacetsProcessor(
 *   id = "date_range_picker",
 *   label = @Translation("Date Range Picker"),
 *   description = @Translation("Display range picker options for date fields."),
 *   stages = {
 *     "build" = 35
 *   }
 * )
 */
class DateRangePickerProcessor extends ProcessorPluginBase implements BuildProcessorInterface {

  /**
   * {@inheritdoc}
   */
  public function build(FacetInterface $facet, array $results) {
    return $results;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state, FacetInterface $facet) {
    $this->getConfiguration();

    $build['start_date'] = [
      '#type' => 'select',
      '#title' => $this->t('Start date field'),
      '#options' => $facet->getFacetSource()->getFields(),
      '#default_value' => $this->getConfiguration()['start_date'],
      '#description' => $this->t('The field should be a timestamp field.'),
      '#required' => TRUE,
    ];

    $build['end_date'] = [
      '#type' => 'select',
      '#title' => $this->t('End date field'),
      '#options' => $facet->getFacetSource()->getFields(),
      '#default_value' => $this->getConfiguration()['end_date'],
      '#description' => $this->t('The field should be a timestamp field.'),
      '#required' => TRUE,
    ];

    $build['overlap'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Overlap'),
      '#default_value' => $this->getConfiguration()['overlap'],
      '#options' => [
        0 => $this->t('Yes'),
        1 => $this->t('No'),
      ],
      '#description' => $this->t('Have overlaps in range.'),
    ];

    $build['options'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Options'),
      '#default_value' => $this->getConfiguration()['options'],
      '#options' => [
        'today' => $this->t('Today'),
        'tomorrow' => $this->t('Tomorrow'),
        'this_weekend' => $this->t('This weekend'),
        'next_seven_days' => $this->t('Next 7 days'),
        'next_fourteen_days' => $this->t('Next 14 days'),
        'next_thirty_days' => $this->t('Next 30 days'),
      ],
    ];

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getQueryType() {
    return 'date_range_picker';
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'start_date' => '',
      'end_date' => '',
      'options' => [],
      'overlap' => 0,
    ];
  }

}
